SystemOrganization addCategory: #ConfigurationOfZTimestamp!

Object subclass: #ConfigurationOfZTimestamp
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfZTimestamp'!

!ConfigurationOfZTimestamp commentStamp: '<historical>' prior: 0!
I am ConfigurationOfZTimestamp, a Metacello configuration to load ZTimestamp.

ZTimestamp, a Magnitude, represents a point in time, a combination of a date and a time.
It is an alternative for DateAndTime and TimeStamp.
It has second precision and lives in the UTC/GMT/Zulu timezone.
It uses ISO/International conventions and protocols only. 
ZTimestamp is more efficient: it uses half the memory of DateAndTime and is faster.!

!ConfigurationOfZTimestamp class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfZTimestamp class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfZTimestamp class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
project

	^self new project! !

!ConfigurationOfZTimestamp class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfZTimestamp methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 6/22/2012 15:10'!
baseline1: spec
	<version: '1-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://mc.stfx.eu/Neo';
			package: 'ZTimestamp' ]! !

!ConfigurationOfZTimestamp methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfZTimestamp methodsFor: 'symbolic versions' stamp: 'SvenVanCaekenberghe 9/3/2012 20:12'!
stable: spec
	<symbolicVersion: #'stable'>
	
	spec for: #common version: '3'! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 6/22/2012 15:49'!
version1: spec
	<version: '1' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.11' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 7/6/2012 17:35'!
version2: spec
	<version: '2' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.12' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/3/2012 20:12'!
version3: spec
	<version: '3' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.15' ]! !
